==> illumination_0.2.20101005-3.tar.gz: illumination-0.2.20101005/include/Lum/ScrolledObject.h <==
/*
  This source is part of the Illumination library
  Copyright (C) 2010  Tim Teulings

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
*/

#include <Lum/Object.h>

namespace Lum {
  class LUMAPI ScrolledObject : public Lum::Scrollable
  {
  private:
    Lum::Object *object;
    bool        horizontalScroll;
    bool        verticalScroll;

  public:
    ScrolledObject();
    ~ScrolledObject();

    bool RequiresKnobs() const;

    ScrolledObject* SetObject(Object *object);
    ScrolledObject* SetScroll(bool horizontalScroll,
                              bool verticalScroll);

    bool VisitChildren(Visitor &visitor, bool onlyVisible);

    void GetDimension(size_t& width, size_t& height);

    void CalcSize();
    void Layout();

    void Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg);

    static ScrolledObject* Create(Object *object,
                                  bool horizontalFlex=false,
                                  bool verticalFlex=false);
  };
}

==> illumination_0.2.20101221-1.tar.gz: illumination-0.2.20101221/include/Lum/ScrolledObject.h <==
/*
  This source is part of the Illumination library
  Copyright (C) 2010  Tim Teulings

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
*/

#include <Lum/Object.h>

namespace Lum {
  class LUMAPI ScrolledObject : public Scrollable
  {
  private:
    Lum::Object *object;
    bool        horizontalScroll;
    bool        verticalScroll;

  public:
    ScrolledObject();
    ~ScrolledObject();

    bool RequiresKnobs() const;

    ScrolledObject* SetObject(Object *object);
    ScrolledObject* SetScroll(bool horizontalScroll,
                              bool verticalScroll);

    bool VisitChildren(Visitor &visitor, bool onlyVisible);

    void GetDimension(size_t& width, size_t& height);

    void CalcSize();
    void Layout();

    void Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg);

    static ScrolledObject* Create(Object *object,
                                  bool horizontalFlex=false,
                                  bool verticalFlex=false);
  };
}
